==> image-data-domain-0.0.96-sources.jar: com/xforceplus/elephant/entity/TicketForm.java <==
package com.xforceplus.elephant.entity;

import java.math.BigDecimal;
import java.time.LocalDateTime;
import java.io.Serializable;
import lombok.Data;
import lombok.EqualsAndHashCode;
import lombok.experimental.Accessors;

/**
 * <p>
 * 
 * </p>
 *
 * @author wangzheng
 * @since 2020-07-01
 */
@Data
@EqualsAndHashCode(callSuper = false)
@Accessors(chain = true)
public class TicketForm implements Serializable {

  private static final long serialVersionUID=1L;

  private Long imageId;

  private String billCode;

  private String batchNo;

  private String warningStatus;

  private String warningInfo;

  private String exceptionStatus;

  private String exceptionInfo;

  private String checkStatus;

  private String checkRemark;

  private String checkTaskId;

  private LocalDateTime checkRequestTime;

  private LocalDateTime checkResponseTime;

  private Long checkUserId;

  private String checkUserName;

  private String isHooked;

  private Long xPoint;

  private Long yPoint;

  private Long width;

  private Long height;

  private Long angle;

  private String ticketCode;

  private BigDecimal amountWithoutTax;

  private BigDecimal taxAmount;

  private BigDecimal amountWithTax;

  private String isPublic;

  private String extFields;

  private String isReuse;

  private String ticketStatus;

  private String reserved1;

  private String reserved2;

  private String reserved3;

  private String isRepeat;

  private String repeatTag;

  private String createUserCode;

  private String systemOrig;

  private String billEntityCode;

  private String reuseTag;

  private String backStatus;

  private LocalDateTime backTime;

  private Long scanUserId;

  private String scanUserName;

  private String isSalesList;

  private String calculateStatus;

  private String relWarningInfo;

  private String relExceptionInfo;

  private String invoiceNo;

  private String invoiceCode;

  private String paperDrewDate;

  private String orderNo;

  private String customerNo;

  private String currencyType;

  private String purchaserTaxNo;

  private String purchaserName;

  private String purchaserCode;

  private String sellerTaxNo;

  private String sellerName;

  private String sellerCode;

  private String remark;

  private String originInvoiceNo;

  private String originInvoiceCode;

  private String originSellerCode;

  private String address;

  private String contractno;

  private String formno;

  /**
   * id
   */
  private Long id;

  /**
   * 租户id
   */
  private Long tenantId;

  /**
   * 租户代码
   */
  private String tenantCode;

  /**
   * 创建时间
   */
  private LocalDateTime createTime;

  /**
   * 修改时间
   */
  private LocalDateTime updateTime;

  /**
   * 创建人
   */
  private Long createUserId;

  /**
   * 修改人
   */
  private Long updateUserId;

  /**
   * 创建人名字
   */
  private String createUserName;

  /**
   * 修改人名字
   */
  private String updateUserName;

  /**
   * 删除标记
   */
  private String deleteFlag;

  private Long ticketFormManyToOneImageId;




        }

==> image-data-domain-0.0.124-sources.jar: com/xforceplus/elephant/entity/TicketForm.java <==
package com.xforceplus.elephant.entity;

import java.math.BigDecimal;
import java.time.LocalDateTime;
import com.baomidou.mybatisplus.annotation.FieldFill;
import com.baomidou.mybatisplus.annotation.TableField;
import java.io.Serializable;
import lombok.Data;
import lombok.EqualsAndHashCode;
import lombok.experimental.Accessors;

/**
 * <p>
 * 
 * </p>
 *
 * @author wangzheng
 * @since 2020-07-31
 */
@Data
@EqualsAndHashCode(callSuper = false)
@Accessors(chain = true)
public class TicketForm implements Serializable {

  private static final long serialVersionUID=1L;

  private Long imageId;

  private String billCode;

  private String batchNo;

  private String warningStatus;

  private String warningInfo;

  private String exceptionStatus;

  private String exceptionInfo;

  private String checkStatus;

  private String checkRemark;

  private String checkTaskId;

  private LocalDateTime checkRequestTime;

  private LocalDateTime checkResponseTime;

  private Long checkUserId;

  private String checkUserName;

  private String isHooked;

  private Long xPoint;

  private Long yPoint;

  private Long width;

  private Long height;

  private Long angle;

  private String ticketCode;

  private BigDecimal amountWithoutTax;

  private BigDecimal taxAmount;

  private BigDecimal amountWithTax;

  private String isPublic;

  private String extFields;

  private String isReuse;

  private String ticketStatus;

  private String reserved1;

  private String reserved2;

  private String reserved3;

  private String isRepeat;

  private String repeatTag;

  private String createUserCode;

  private String systemOrig;

  private String billEntityCode;

  private String reuseTag;

  private String backStatus;

  private LocalDateTime backTime;

  private Long scanUserId;

  private String scanUserName;

  private String isSalesList;

  private String calculateStatus;

  private String relWarningInfo;

  private String relExceptionInfo;

  private String invoiceNo;

  private String invoiceCode;

  private String paperDrewDate;

  private String orderNo;

  private String customerNo;

  private String currencyType;

  private String purchaserTaxNo;

  private String purchaserName;

  private String purchaserCode;

  private String sellerTaxNo;

  private String sellerName;

  private String sellerCode;

  private String remark;

  private String originInvoiceNo;

  private String originInvoiceCode;

  private String originSellerNo;

  private String address;

  private String contractno;

  private String formno;

  private String purchaserNo;

  private String sellerNo;

  private LocalDateTime invoiceDate;

  /**
   * id
   */
  private Long id;

  /**
   * 租户id
   */
  @TableField(fill = FieldFill.INSERT)
  private Long tenantId;

  /**
   * 租户代码
   */
  @TableField(fill = FieldFill.INSERT)
  private String tenantCode;

  /**
   * 创建时间
   */
  @TableField(fill = FieldFill.INSERT)
  private LocalDateTime createTime;

  /**
   * 修改时间
   */
  @TableField(fill = FieldFill.INSERT_UPDATE)
  private LocalDateTime updateTime;

  /**
   * 创建人
   */
  @TableField(fill = FieldFill.INSERT)
  private Long createUserId;

  /**
   * 修改人
   */
  @TableField(fill = FieldFill.INSERT_UPDATE)
  private Long updateUserId;

  /**
   * 创建人名字
   */
  @TableField(fill = FieldFill.INSERT)
  private String createUserName;

  /**
   * 修改人名字
   */
  @TableField(fill = FieldFill.INSERT_UPDATE)
  private String updateUserName;

  /**
   * 删除标记
   */
  @TableField(fill = FieldFill.INSERT)
  private String deleteFlag;

  private Long ticketFormManyToOneImageId;




        }
